==> distribution-6.19.3.zip: drr/projection/iso20022/hkma/rewrite/trade/dtcc/functions/Create_PartyIdentification248Choice__5.java <==
package drr.projection.iso20022.hkma.rewrite.trade.dtcc.functions;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.functions.ModelObjectValidator;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperS;
import drr.regulation.common.HKTRPartyScheme;
import drr.regulation.common.PartyIdentifierFormat2Enum;
import drr.regulation.hkma.rewrite.trade.HKMATransactionReport;
import iso20022.auth030.hkma.dtcc.GenericIdentification175__1;
import iso20022.auth030.hkma.dtcc.LegalPersonIdentification1__5;
import iso20022.auth030.hkma.dtcc.NaturalPersonIdentification2__1;
import iso20022.auth030.hkma.dtcc.NaturalPersonIdentification3__2;
import iso20022.auth030.hkma.dtcc.OrganisationIdentification15Choice__2;
import iso20022.auth030.hkma.dtcc.PartyIdentification248Choice__5;
import java.util.Optional;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(Create_PartyIdentification248Choice__5.Create_PartyIdentification248Choice__5Default.class)
public abstract class Create_PartyIdentification248Choice__5 implements RosettaFunction {
	
	@Inject protected ModelObjectValidator objectValidator;
	
	// RosettaFunction dependencies
	//
	@Inject protected Create_OrganisationIdentification15Choice__2 create_OrganisationIdentification15Choice__2;

	/**
	* @param drrReport 
	* @return id 
	*/
	public PartyIdentification248Choice__5 evaluate(HKMATransactionReport drrReport) {
		PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder idBuilder = doEvaluate(drrReport);
		
		final PartyIdentification248Choice__5 id;
		if (idBuilder == null) {
			id = null;
		} else {
			id = idBuilder.build();
			objectValidator.validate(PartyIdentification248Choice__5.class, id);
		}
		
		return id;
	}

	protected abstract PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder doEvaluate(HKMATransactionReport drrReport);

	public static class Create_PartyIdentification248Choice__5Default extends Create_PartyIdentification248Choice__5 {
		@Override
		protected PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder doEvaluate(HKMATransactionReport drrReport) {
			PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder id = PartyIdentification248Choice__5.builder();
			return assignOutput(id, drrReport);
		}
		
		protected PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder assignOutput(PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder id, HKMATransactionReport drrReport) {
			OrganisationIdentification15Choice__2 ifThenElseResult0 = null;
			if (notEqual(MapperS.of(drrReport).<HKTRPartyScheme>map("getCounterparty2SchemeName", hKMATransactionReport -> hKMATransactionReport.getCounterparty2SchemeName()), MapperS.of(HKTRPartyScheme.TRID), CardinalityOperator.Any).getOrDefault(false)) {
				ifThenElseResult0 = create_OrganisationIdentification15Choice__2.evaluate(drrReport, MapperS.of(drrReport).<PartyIdentifierFormat2Enum>map("getCounterparty2IdentifierFormat", hKMATransactionReport -> hKMATransactionReport.getCounterparty2IdentifierFormat()).get(), MapperS.of(drrReport).<String>map("getCounterparty2", hKMATransactionReport -> hKMATransactionReport.getCounterparty2()).get(), MapperS.of(drrReport).<HKTRPartyScheme>map("getCounterparty2SchemeName", hKMATransactionReport -> hKMATransactionReport.getCounterparty2SchemeName()).get());
			}
			NaturalPersonIdentification3__2 ifThenElseResult1 = null;
			if (areEqual(MapperS.of(drrReport).<Boolean>map("getCounterparty2IdentifierType", hKMATransactionReport -> hKMATransactionReport.getCounterparty2IdentifierType()), MapperS.of(false), CardinalityOperator.All).and(areEqual(MapperS.of(drrReport).<PartyIdentifierFormat2Enum>map("getCounterparty2IdentifierFormat", hKMATransactionReport -> hKMATransactionReport.getCounterparty2IdentifierFormat()), MapperS.of(PartyIdentifierFormat2Enum.NATURAL_PERSON), CardinalityOperator.All)).getOrDefault(false)) {
				ifThenElseResult1 = NaturalPersonIdentification3__2.builder()
					.setId(NaturalPersonIdentification2__1.builder()
						.setId(GenericIdentification175__1.builder()
							.setId(MapperS.of(drrReport).<String>map("getCounterparty2", hKMATransactionReport -> hKMATransactionReport.getCounterparty2()).get())
							.build())
						.build())
					.build();
			}
			id = toBuilder(PartyIdentification248Choice__5.builder()
				.setLgl(LegalPersonIdentification1__5.builder()
					.setId(ifThenElseResult0)
					.build())
				.setNtrl(ifThenElseResult1)
				.build());
			
			return Optional.ofNullable(id)
				.map(o -> o.prune())
				.orElse(null);
		}
	}
}

==> distribution-6.24.0.zip: drr/projection/iso20022/hkma/rewrite/trade/dtcc/functions/Create_PartyIdentification248Choice__5.java <==
package drr.projection.iso20022.hkma.rewrite.trade.dtcc.functions;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.functions.ModelObjectValidator;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperS;
import drr.regulation.common.HKTRPartyScheme;
import drr.regulation.common.PartyIdentifierFormat2Enum;
import drr.regulation.hkma.rewrite.trade.HKMATransactionReport;
import iso20022.auth030.hkma.dtcc.GenericIdentification175__1;
import iso20022.auth030.hkma.dtcc.LegalPersonIdentification1__5;
import iso20022.auth030.hkma.dtcc.NaturalPersonIdentification2__1;
import iso20022.auth030.hkma.dtcc.NaturalPersonIdentification3__2;
import iso20022.auth030.hkma.dtcc.OrganisationIdentification15Choice__2;
import iso20022.auth030.hkma.dtcc.PartyIdentification248Choice__5;
import java.util.Optional;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

@ImplementedBy(Create_PartyIdentification248Choice__5.Create_PartyIdentification248Choice__5Default.class)
public abstract class Create_PartyIdentification248Choice__5 implements RosettaFunction {
	
	@Inject protected ModelObjectValidator objectValidator;
	
	// RosettaFunction dependencies
	//
	@Inject protected Create_OrganisationIdentification15Choice__2 create_OrganisationIdentification15Choice__2;

	/**
	* @param drrReport 
	* @return id 
	*/
	public PartyIdentification248Choice__5 evaluate(HKMATransactionReport drrReport) {
		PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder idBuilder = doEvaluate(drrReport);
		
		final PartyIdentification248Choice__5 id;
		if (idBuilder == null) {
			id = null;
		} else {
			id = idBuilder.build();
			objectValidator.validate(PartyIdentification248Choice__5.class, id);
		}
		
		return id;
	}

	protected abstract PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder doEvaluate(HKMATransactionReport drrReport);

	public static class Create_PartyIdentification248Choice__5Default extends Create_PartyIdentification248Choice__5 {
		@Override
		protected PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder doEvaluate(HKMATransactionReport drrReport) {
			PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder id = PartyIdentification248Choice__5.builder();
			return assignOutput(id, drrReport);
		}
		
		protected PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder assignOutput(PartyIdentification248Choice__5.PartyIdentification248Choice__5Builder id, HKMATransactionReport drrReport) {
			OrganisationIdentification15Choice__2 ifThenElseResult0 = null;
			if (notEqual(MapperS.of(drrReport).<HKTRPartyScheme>map("getCounterparty2SchemeName", hKMATransactionReport -> hKMATransactionReport.getCounterparty2SchemeName()), MapperS.of(HKTRPartyScheme.TRID), CardinalityOperator.Any).getOrDefault(false)) {
				ifThenElseResult0 = create_OrganisationIdentification15Choice__2.evaluate(drrReport, MapperS.of(drrReport).<PartyIdentifierFormat2Enum>map("getCounterparty2IdentifierFormat", hKMATransactionReport -> hKMATransactionReport.getCounterparty2IdentifierFormat()).get(), MapperS.of(drrReport).<String>map("getCounterparty2", hKMATransactionReport -> hKMATransactionReport.getCounterparty2()).get(), MapperS.of(drrReport).<HKTRPartyScheme>map("getCounterparty2SchemeName", hKMATransactionReport -> hKMATransactionReport.getCounterparty2SchemeName()).get());
			}
			NaturalPersonIdentification3__2 ifThenElseResult1 = null;
			if (areEqual(MapperS.of(drrReport).<Boolean>map("getCounterparty2IdentifierType", hKMATransactionReport -> hKMATransactionReport.getCounterparty2IdentifierType()), MapperS.of(false), CardinalityOperator.All).andNullSafe(areEqual(MapperS.of(drrReport).<PartyIdentifierFormat2Enum>map("getCounterparty2IdentifierFormat", hKMATransactionReport -> hKMATransactionReport.getCounterparty2IdentifierFormat()), MapperS.of(PartyIdentifierFormat2Enum.NATURAL_PERSON), CardinalityOperator.All)).getOrDefault(false)) {
				ifThenElseResult1 = NaturalPersonIdentification3__2.builder()
					.setId(NaturalPersonIdentification2__1.builder()
						.setId(GenericIdentification175__1.builder()
							.setId(MapperS.of(drrReport).<String>map("getCounterparty2", hKMATransactionReport -> hKMATransactionReport.getCounterparty2()).get())
							.build())
						.build())
					.build();
			}
			id = toBuilder(PartyIdentification248Choice__5.builder()
				.setLgl(LegalPersonIdentification1__5.builder()
					.setId(ifThenElseResult0)
					.build())
				.setNtrl(ifThenElseResult1)
				.build());
			
			return Optional.ofNullable(id)
				.map(o -> o.prune())
				.orElse(null);
		}
	}
}
